Generate WhatsApp SDK service, resource, and registry modules from an OpenAPI specification.
$ mix whatsapp.generate
$ mix whatsapp.generate --clean
$ mix whatsapp.generate --dry-run
$ mix whatsapp.generate --stats
Options
--clean- delete previously generated files before regenerating--dry-run- parse and compute what would be generated without writing files--stats- print generation statistics after generating
The task looks for the first .json file in priv/openapi/ and uses it
as the OpenAPI specification source.